summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/attic/qtmultilineedit.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commit03256f3cd5149f3ff5f5f45765b0b0659db4e036 (patch)
treecaabe9e1c0e3edfd06ea5aefd4d7279664cd9ede /experimental/tqtinterface/qt4/src/attic/qtmultilineedit.cpp
parent0594950f65a713c2d12e8eb6ddd3f5f9b306ec08 (diff)
downloadtde-03256f3cd5149f3ff5f5f45765b0b0659db4e036.tar.gz
tde-03256f3cd5149f3ff5f5f45765b0b0659db4e036.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'experimental/tqtinterface/qt4/src/attic/qtmultilineedit.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/attic/qtmultilineedit.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/experimental/tqtinterface/qt4/src/attic/qtmultilineedit.cpp b/experimental/tqtinterface/qt4/src/attic/qtmultilineedit.cpp
index 203ed5643..8442e1472 100644
--- a/experimental/tqtinterface/qt4/src/attic/qtmultilineedit.cpp
+++ b/experimental/tqtinterface/qt4/src/attic/qtmultilineedit.cpp
@@ -6,7 +6,7 @@
**
** Copyright (C) 2010 Timothy Pearson and (C) 1992-2008 Trolltech ASA.
**
** This file tqcontains a class moved out of the TQt GUI Toolkit API. It
** may be used, distributed and modified without limitation.
**
**********************************************************************/
@@ -187,7 +187,7 @@ edited flag is never read by TQtMultiLineEdit, but is changed to TRUE
whenever the user changes its contents.
This is useful e.g. for things that need to provide a default value,
-but cannot tqfind the default at once. Just open the widget without the
+but cannot find the default at once. Just open the widget without the
best default and when the default is known, check the edited() return
value and set the line edit's contents if the user has not started
editing the line edit. Another example is to detect whether the
@@ -1058,7 +1058,7 @@ TQString TQtMultiLineEdit::textLine( int line ) const
/*
- Returns a copy of the whole text. If the multi line edit tqcontains no
+ Returns a copy of the whole text. If the multi line edit contains no
text, a
\link TQString::operator!() null string\endlink
is returned.
@@ -1568,9 +1568,9 @@ void TQtMultiLineEdit::insertAtAux( const TQString &txt, int line, int col, bool
cursorX += itxt.length();
}
TQFontMetrics fm( font() );
- if ( !WORD_WRAP || ( col == 0 && itxt.tqcontains('\n') == int(itxt.length())) )
+ if ( !WORD_WRAP || ( col == 0 && itxt.contains('\n') == int(itxt.length())) )
wrapLine( line, 0 );
- else if ( WORD_WRAP && itxt.tqfind('\n')<0 && itxt.tqfind('\t')<0
+ else if ( WORD_WRAP && itxt.find('\n')<0 && itxt.find('\t')<0
&& (
( DYNAMIC_WRAP && fm.width( itxt ) + row->w < contentsRect().width() - 2*d->lr_marg - d->marg_extra )
||
@@ -1578,7 +1578,7 @@ void TQtMultiLineEdit::insertAtAux( const TQString &txt, int line, int col, bool
||
( FIXED_COLUMN_WRAP && ( d->wrapcol < 0 || int(row->s.length()) < d->wrapcol ) )
)
- && ( itxt.tqfind(' ') < 0 || row->s.tqfind(' ') >= 0 && row->s.tqfind(' ') < col ) ){
+ && ( itxt.find(' ') < 0 || row->s.find(' ') >= 0 && row->s.find(' ') < col ) ){
row->w = textWidth( row->s );
setWidth( TQMAX( maxLineWidth(), row->w) );
updateCell( line, 0, FALSE );
@@ -1612,7 +1612,7 @@ void TQtMultiLineEdit::insertAtAux( const TQString &txt, int line, int col, bool
/*
Inserts \a txt at line number \a line. If \a line is less than zero,
or larger than the number of rows, the new text is put at the end.
- If \a txt tqcontains newline characters, several lines are inserted.
+ If \a txt contains newline characters, several lines are inserted.
The cursor position is not changed.
*/
@@ -2232,7 +2232,7 @@ void TQtMultiLineEdit::mousePressEvent( TQMouseEvent *e )
void TQtMultiLineEdit::pixelPosToCursorPos(TQPoint p, int* x, int* y) const
{
- *y = tqfindRow( p.y() );
+ *y = findRow( p.y() );
if ( *y < 0 ) {
if ( p.y() < lineWidth() ) {
*y = topCell();
@@ -2309,7 +2309,7 @@ void TQtMultiLineEdit::mouseMoveEvent( TQMouseEvent *e )
#endif
if ( !dragMarking )
return;
- if ( rect().tqcontains( e->pos() ) ) {
+ if ( rect().contains( e->pos() ) ) {
stopAutoScroll();
} else if ( !dragScrolling ) {
startAutoScroll();
@@ -2442,7 +2442,7 @@ void TQtMultiLineEdit::dragMoveEvent( TQDragMoveEvent* event )
d->dnd_forcecursor = FALSE;
TQRect inside_margin(scroll_margin, scroll_margin,
width()-scroll_margin*2, height()-scroll_margin*2);
- if ( !inside_margin.tqcontains(event->pos()) ) {
+ if ( !inside_margin.contains(event->pos()) ) {
startAutoScroll();
}
if ( event->source() == this && event->action() == TQDropEvent::Move )
@@ -2469,8 +2469,8 @@ void TQtMultiLineEdit::dropEvent( TQDropEvent* event )
TQCString fmt = pickSpecial(event,FALSE,event->pos());
if ( TQTextDrag::decode(event, text, fmt) ) {
int i = -1;
- while ( ( i = text.tqfind( '\r' ) ) != -1 )
- text.tqreplace( i,1,"" );
+ while ( ( i = text.find( '\r' ) ) != -1 )
+ text.replace( i,1,"" );
if ( event->source() == this && event->action() == TQDropEvent::Move ) {
event->acceptAction();
// Careful not to tread on my own feet
@@ -2597,7 +2597,7 @@ int TQtMultiLineEdit::mapToView( int xIndex, int line )
}
/*
- Traverses the list and tqfinds an item with the maximum width, and
+ Traverses the list and finds an item with the maximum width, and
updates the internal list box structures accordingly.
*/
@@ -2665,7 +2665,7 @@ void TQtMultiLineEdit::pasteSubType(const TQCString& subtype)
#if defined(_OS_WIN32_)
// Need to convert CRLF to NL
- t.tqreplace( "\r\n", "\n" );
+ t.replace( "\r\n", "\n" );
#endif
for (int i=0; (uint)i<t.length(); i++) {
@@ -2714,12 +2714,12 @@ TQCString TQtMultiLineEdit::pickSpecial(TQMimeSource* ms, bool always_ask, const
int n=0;
TQDict<void> done;
for (int i=0; !(fmt=ms->format(i)).isNull(); i++) {
- int semi=fmt.tqfind(";");
+ int semi=fmt.find(";");
if ( semi >= 0 )
fmt = fmt.left(semi);
if ( fmt.left(5) == "text/" ) {
fmt = fmt.mid(5);
- if ( !done.tqfind(fmt) ) {
+ if ( !done.find(fmt) ) {
done.insert(fmt,(void*)1);
popup.insertItem(fmt,i);
n++;
@@ -2880,7 +2880,7 @@ void TQtMultiLineEdit::copy() const
#endif
#if defined(_OS_WIN32_)
// Need to convert NL to CRLF
- t.tqreplace( "\n", "\r\n" );
+ t.replace( "\n", "\r\n" );
#endif
TQApplication::clipboard()->setText( t );
#if defined(_WS_X11_)
@@ -3957,7 +3957,7 @@ void TQtMultiLineEdit::redo()
/*
Inserts \a s at line number \a line, after character number \a col
in the line.
- If \a s tqcontains newline characters, new lines are inserted.
+ If \a s contains newline characters, new lines are inserted.
If \a mark is TRUE the inserted text is selected.
The cursor position is adjusted. If the insertion position is equal to
@@ -6,7 +6,7 @@
** Copyright (C) 2010 Timothy Pearson and (C) 1992-2008 Trolltech ASA.
**
-** This file tqcontains a class moved out of the TQt GUI Toolkit API. It
+** This file contains a class moved out of the TQt GUI Toolkit API. It
** may be used, distributed and modified without limitation.
**